<?php
require_once 'models/BaseModel.php';
require_once 'models/WebPropertyAnalysis.php';

class WebProperty extends BaseModel
{
    protected $_resultsList;
    protected $_url;
    
    public function __construct($identifier)
    {
        $id = -1;
        $url = '';
        $this->_resultsList = array();                     
        
        if (is_string($identifier) and !empty($identifier))  {
            $id = $this->findIdFromUrl($identifier);
            $this->_url = $identifier;
        } else if (is_numeric($identifier) and $identifier>0) {
            $id = (int)$identifier;
        } // if (is_string($identifier) and !empty($identifier))  

        if ($id>0) {
            $this->load($id);
        } else {
            $this->_data = array('id'  => $id,
                                 'url' => $url);
        } // if ($id>0)
        return;
    } // public function __construct($id)
    
    
    public function load($id, $loadAnalyzations=false)
    {
        $db = Globals::getDBConnection();
        
        $sql = 'SELECT * FROM web_property WHERE id = ?';

        if ($result = $db->fetchRow($sql, array($id))) {
            $this->_data = $result;
            $this->_id = $id;
            $this->_url = $this->_data['url'];
        } // if ($result = $db->fetchRow($sql, array($id)))
        
        if ($loadAnalyzations) {
            $this->loadAnalyzations();
        } // if ($loadAnalyzations)
        
        return;
    } // public function load($id)
    
    
    public function loadAnalyzations()
    {
        $db = Globals::getDBConnection();
        $sql = 'SELECT id
                  FROM web_property_analysis
                 WHERE web_property_id = ?
                 ORDER BY search_date';

        if ($result = $db->fetchAll($sql, array($this->_id))) {
            foreach($result as $analysis) {
                $this->_resultsList[(int)$analysis['id']] = new WebPropertyAnalysis((int)$analysis['id']);
            } // foreach($result as $analysisId)
        } // if ($result = $db->fetchAll($sql, array($this->_id)))
        return;
    } // public function loadanalyzations()
    
    
    public function save()
    {
        $db = Globals::getDBConnection();
        $data = array();
        $data['url'] = $this->_url;
        if (!$this->_id) {            
            $db->insert('web_property', $data);
            $this->_id = $db->lastInsertId();
        } else {
            $db->update('web_property', $data, 'id = '.(int)$this->_id);
        } // if ($memberId)
        
        Globals::getCache()->remove('searchList');
        
    } // public function save()
    
    
    protected function findIdFromUrl($url=null)
    {
        $returnValue = -1;
        
        $db = Globals::getDBConnection();
        $sql = 'SELECT id FROM web_property WHERE url = ?';

        if ($result = $db->fetchOne($sql, array($url))) {
            $returnValue = $result;
        } // if ($result = $db->fetchOne($sql, array($url)))
        
        return $returnValue;
    } // protected function findIdFromUrl($url=null)
    
    
    public function addAnalysis($date, $results) {

        if ($this->_id>0) {
            $wpa = new WebPropertyAnalysis();
            $wpa->web_property_id = $this->_id;
            $wpa->search_date = $date;
            foreach($results as $word) {
                $wpa->addKeyWord($word);
            } // foreach($results as $word)
            $wpa->save();
            $this->_resultsList[$wpa->id] = $wpa;
            return true;
        } // if ($this->id>0)
        
        return false;
    } // public addAnalysis($date, $results) 
   
   
    public function fetchAnalysis($id=-1)
    {
        if (isset($this->_resultsList[$id])) {
            return $this->_resultsList[$id]->fetchResultsList();
        }
        return null;
    } // public function fetchAnalysis($id=-1)
    

    public function analyze()
    {
            if (substr(strtolower($this->_url),0,7)!='http://') {
                throw new Zend_Exception("All URLs must start with http://");
            } // if (substr(strtolower($url),0,7)!='http://')
            
            /*
             * read page into memory
             * requires allow_url_fopen to be true
             */
            $page = file_get_contents($this->_url);
            
            
            if (!$page) {
                throw new Zend_Exception("There was an error loading the url. ".$this->_url);
            } // if (substr(strtolower($url),0,7)!='http://')
            
            /*
             * strip out everything but the content
             * Many thanks to #phpc members ds3 and SlashLife for the RegEx
             */
            $matches = array();
            preg_match('/<body[^>]*>(.*?)<\/body\s*/isx', $page, $matches);
            $content = $matches[1];
            
            /*
             * Filter out the cruft
             */
            $content = preg_replace('/(<style[^>]*>[^>]*<\/style\s*>)/isx', '', $content);
            $content = preg_replace('/(<script[^>]*>[^>]*<\/script\s*>)/isx', '', $content);
            $content = preg_replace('/(&.*?;)/isx', '', $content);
            
            $content = Zend_Filter::get($content, 'StripTags');
            
            
            /*
             * send it off to Yahoo for analysis
             * 
             */
            $client = new Zend_Rest_Client(Globals::getConfig()->url->yahoo);
            $client->appid(Globals::getConfig()->yahooAppId)
                   ->context($content)
                   ->output('xml');
            $result = $client->post();
            $client = null;

            if (!empty($result->Message)) {
                throw new Zend_Exception((string)$result->Message);
            } // if ($result->isError())

            $firstResponse = (string)$result->Result[0];
            if (empty($firstResponse)) {
                throw new Zend_Exception('Yahoo was not able to find any keywords.');
            } // if (!isArray($result))
            /*
             * Build our keywords list
             */
            $keywords    = array();
            $returnValue = array();
            
            foreach($result->Result as $item) {
                $thisItem = (string)$item;
                if (empty($thisItem)) {
                    continue;
                }
                $image = $this->fetchImageTag($thisItem);
                $returnValue[] = array($thisItem,
                                              $image);
                $keywords[] = $thisItem;
            } // foreach($result->Result as $item) 
            $this->addAnalysis(date('Y-m-d h:i:s',mktime()),$keywords);
            
            return $returnValue; 
    } // public function analyze()
    
    
    public function fetchImageTag($word)
    {
        $cache = Globals::getCache();
        $cacheKey = md5("keyword_image".$word);
        if (!$results = $cache->load($cacheKey)) {
            $flickr = new Zend_Service_Flickr(Globals::getConfig()->flickerKey);
            $flikrResults = $flickr->tagSearch(
               (string)$word,
               array('per_page' => 1,
                     'page'     => 1,
                     'sort'     => 'interestingness-desc'));
                
            if ($flikrResults->valid()) {
                $results = '<img src="'.$flikrResults->current()->Small->uri.'" title="'.$word.'"/>';
            } else {
                $results = '';            
            } // if ($flikrResults->valid())
            if (!empty($results)) {
                $cache->save($results, $cacheKey,array('images'),(86400*3));
            } // if (!empty($results))
        } // if (!$results = $cache->load($cacheKey)
        return $results;
    } // public function fetchPhoto($word)
    
} // class WebProperty extends BaseModel