<?php
require_once 'models/BaseModel.php';
require_once 'models/WebPropertyAnalysis.php';

class WebProperty extends BaseModel
{
    protected $_resultsList;
    
    public function __construct($identifier)
    {
        $id = -1;
        $url = '';
        $this->_resultsList = array();                     
        
        if (is_string($identifier) and !empty($identifier))  {
            $id = $this->findIdFromUrl($identifier);
            $url = $identifier;
        } else if (is_numeric($identifier) and $identifier>0) {
            $id = (int)$identifier;
        } // if (is_string($identifier) and !empty($identifier))  

        if ($id>0) {
            $this->load($id);
        } else {
            $this->_data = array('id'  => $id,
                                 'url' => $url);
        } // if ($id>0)
        return;
    } // public function __construct($id)
    
    
    public function load($id, $loadAnalyzations=false)
    {
        $db = Globals::getDBConnection();
        
        $sql = 'SELECT * FROM web_property WHERE id = ?';

        if ($result = $db->fetchRow($sql, array($id))) {
            $this->_data = $result;
            $this->_id = $id;
        } // if ($result = $db->fetchRow($sql, array($id)))
        
        if ($loadAnalyzations) {
            $this->loadAnalyzations();
        } // if ($loadAnalyzations)
        
        return;
    } // public function load($id)
    
    
    public function loadAnalyzations()
    {
        $db = Globals::getDBConnection();
        $sql = 'SELECT id
                  FROM web_property_analysis
                 WHERE web_property_id = ?
                 ORDER BY search_date';

        if ($result = $db->fetchAll($sql, array($this->_id))) {
            foreach($result as $analysis) {
                $this->_resultsList[(int)$analysis['id']] = new WebPropertyAnalysis((int)$analysis['id']);
            } // foreach($result as $analysisId)
        } // if ($result = $db->fetchAll($sql, array($this->_id)))
        return;
    } // public function loadanalyzations()
    
    
    public function save()
    {
        $db = Globals::getDBConnection();
        $data = array();
        $data['url'] = $this->url;
        if (!$this->_id) {            
            $db->insert('web_property', $data);
            $this->_id = $db->lastInsertId();
        } else {
            $db->update('web_property', $data, 'id = '.(int)$this->_id);
        } // if ($memberId)
        
        Globals::getCache()->remove('searchList');
        
    } // public function save()
    
    
    protected function findIdFromUrl($url=null)
    {
        $returnValue = -1;
        
        $db = Globals::getDBConnection();
        $sql = 'SELECT id FROM web_property WHERE url = ?';

        if ($result = $db->fetchOne($sql, array($url))) {
            $returnValue = $result;
        } // if ($result = $db->fetchOne($sql, array($url)))
        
        return $returnValue;
    } // protected function findIdFromUrl($url=null)
    
    
    public function addAnalysis($date, $results) {

        if ($this->_id>0) {
            $wpa = new WebPropertyAnalysis();
            $wpa->web_property_id = $this->_id;
            $wpa->search_date = $date;
            foreach($results as $word) {
                $wpa->addKeyWord($word[0]);
            } // foreach($results as $word)
            $wpa->save();
            $this->_resultsList[$wpa->id] = $wpa;
            return true;
        } // if ($this->id>0)
        
        return false;
    } // public addAnalysis($date, $results) 
   
   
    public function fetchAnalysis($id=-1)
    {
        if (isset($this->_resultsList[$id])) {
            return $this->_resultsList[$id]->fetchResultsList();
        }
        return null;
    } // public function fetchAnalysis($id=-1)
    
    
    public function fetchImageTag($word)
    {
        $cache = Globals::getCache();
        $cacheKey = md5("keyword_image".$word);
        if (!$results = $cache->load($cacheKey)) {
            $flickr = new Zend_Service_Flickr(Globals::getConfig()->flickerKey);
            $flikrResults = $flickr->tagSearch(
               (string)$word,
               array('per_page' => 1,
                     'page'     => 1,
                     'sort'     => 'interestingness-desc'));
                
            if ($flikrResults->valid()) {
                $results = '<img src="'.$flikrResults->current()->Medium->uri.'" title="'.$word.'"/>';
            } else {
                $results = '';            
            } // if ($flikrResults->valid())
            if (!empty($results)) {
                $cache->save($results, $cacheKey,array('images'),(86400*3));
            } // if (!empty($results))
        } // if (!$results = $cache->load($cacheKey)
        return $results;
    } // public function fetchPhoto($word)
    
} // class WebProperty extends BaseModel