<?php

/**
 * Zend Framework
 *
 * LICENSE
 *
 * This source file is subject to the new BSD license that is bundled
 * with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://framework.zend.com/license/new-bsd
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@zend.com so we can send you a copy immediately.
 *
 * @category   Zend
 * @package    Zend_Controller
 * @copyright  Copyright (c) 2005-2007 Zend Technologies USA Inc. (http://www.zend.com)
 * @license    http://framework.zend.com/license/new-bsd     New BSD License
 */ 


/**
 * @category   Zend
 * @package    Zend_Controller
 * @copyright  Copyright (c) 2005-2007 Zend Technologies USA Inc. (http://www.zend.com)
 * @license    http://framework.zend.com/license/new-bsd     New BSD License
 */

/** Zend_Controller_Request_Abstract */
require_once 'Zend/Controller/Request/Abstract.php';

/** Zend_Console_Getopt */
require_once 'Zend/Console/Getopt.php';

class Zend_Controller_Request_Cli extends Zend_Controller_Request_Abstract
{
    /**
     * an instance of Zend_Console_Getopt
     * @var object
     */
    protected $getopt;

    /**
     * path info for searching for classes
     * @var string 
     */
    protected $_pathInfo;
    
    /**
     * constructor
     *
     * takes in the rules for getopt and instantiates an instace of it.
     *
     * There are 3 magic rules that, if set, will be used:
     * $rules['m|module-s']     = '';
     * $rules['c|controller-s'] = '';
     * $rules['a|action-s']     = '';
     *
     * @param array properly formatted Getops rules array.
     * @return void
     */
    public function __construct($rules=array())    
    {
        if (count($rules)>0) {
            $this->getopt = new Zend_Console_Getopt($rules);
        
            $this->getopt->parse();

            if (!is_null($this->getOption($this->_moduleKey))) {
                $this->_module = $this->get($this->_moduleKey);
            }

            if (!is_null($this->getOption($this->_controllerKey))) {
                $this->setControllerName($this->getOption($this->_controllerKey));
            }

            if (!is_null($this->getOption($this->_actionKey))) {
                $this->_action = $this->getOption($this->_actionKey);
            }
        }
    }

    
    /**
     * getOption
     *
     * retrieves a command line option.
     *
     * @return multi
     */
    public function getOption($key)
    {
        return $this->getopt->getOption($key);
    }


    /**
     * getOptions
     *
     * fetches an associative array of options and their values from Getopt
     *
     * @return array
     */
    public function getOptions()    
    {
        $keyList = $this->getopt->getOptions();
        $returnValue = array();
        foreach($keyList as $key) {
            $returnValue[$key] = $this->getopt->getOption($key);
        }
        return $returnValue;
    }
    
    
    /**
     * setPathInfo
     *
     * sets the PathInfo parameter. PathInfo needs to be moved to Abstract because Router calls it.
     *
     * @param string the new path.
     * @return void
     */
    public function setPathInfo($pathInfo = null)
    {
        $this->_pathInfo = $pathinfo;
    }


    /**
     * getPathInfo
     *
     * retrieves the PathInfo parameter.
     *
     * @return string
     */
    public function getPathInfo()
    {
        return $this->_pathInfo;
    }
    
}
