<?php
require_once 'controllers/BaseController.php';
require_once 'models/WebProperty.php';

class ApiController extends BaseController
{

    public function init()
    {
        $this->_helper->viewRenderer->setNoRender();    
    } // public function init()
    
    public function fetchTopAction()
    {
        $limit  = (int)Zend_Filter::get($this->getRequest()->get('limit'), 'StripTags');
        
        $db = Globals::getDBConnection();
        
        $select = $db->select(array('keyword'))
                     ->from(array('wpa'=>'web_property_analysis_result'),array('keyword','keyword_count'=>'count(*)'))
                     ->group('wpa.keyword')
                     ->order(array('keyword_count DESC','keyword'))
                     ->limit($limit, 0);

        $results = $db->fetchAll($select);

        echo $this->toXML($results,'fetchTop',$limit);
        return;
    } // public function fetchTopAction()
    
    
    public function fetchTermAction()
    {
        $output = '';
        
        try {
            $term  = Zend_Filter::get($this->getRequest()->get('term'), 'StripTags');
            
            $db = Globals::getDBConnection();
            
            $select = $db->select()
                         ->from(array('wpa'=>'web_property_analysis_result'),array('wpa.keyword','keyword_count'=>'count(*)'))
                         ->group('wpa.keyword')
                         ->where('keyword=?',$term);
    
            $results = $db->fetchAll($select);        
            echo $this->toXML($results,'fetchTerm',$term);
        } catch (Zend_Eception $e) {
            $results = array('There was an error processing the request.',$e->message);
            echo $this->toXML($results,'fetchTerm',$term);
        }
        return;
    } // public function fetchTerm()


    public function extractAction()
    {
        $payload = array();
        
        try {
            /*
             * get the token
             */
            $token = Zend_Filter::get($this->getRequest()->get('token'), 'StripTags');
            
            /*
             * Execute the token check
             */
            if (!$this->tokenCheck($token)) {
                throw new Zend_Exception("I'm sorry but I think there has been an error. Please try again.");
            } // if (!$this->tokenCheck($token))
            /*
             * Reset the token
             */
            $newToken = $this->generateToken();
            
            /*
             * get the URL passed in from the form
             */
            $url = Zend_Filter::get($this->getRequest()->get('url'), 'StripTags');
            
            if (substr(strtolower($url),0,7)!='http://') {
                $url = 'http://'.trim($url);
            } // if (substr(strtolower($url),0,7)!='http://')
            
            $wp  = new WebProperty($url);
            
            /*
             * prepare the payload
             */
            $payload['token'] = $newToken;
            
            $payload['message'] = array('Success');
            $payload['url']     = $url ;
            $payload['result']  = $wp->analyze();
            
            $wp->save();
            
        } catch (Zend_Exception $e) {
            /*
             * Deal with exceptions.
             */
            $payload['token'] = $newToken;
            $payload['message'] = array();
            $payload['message'][] = "There was an error processing your request.";
            $payload['message'][] = "Exception Type:".get_class($e);
            $payload['message'][] = "Exception Message:".$e->getMessage();
        }
        $this->getResponse()->setHeader('Content-Type','application/json')
                            ->setHeader('X-JSON',Zend_Json::encode($payload))
                            ->appendBody('');
        return ;

    } // public function extractAction()


    public function getTokenAction()
    {
        $token = Zend_Filter::get($this->getRequest()->getPost('token'), 'StripTags');
        $payload = array();
        $payload['message'] = '';
        $payload['token'] = $this->generateToken();
        
        if (!$this->tokenCheck($token)) {
            $payload['status'] = false;
            $payload['message'] = "Token Validation Error.";
            $payload['token'] = null;
        } else {
            $payload['status'] = true;
            $payload['message'] = "Success";
        } // if (!$this->tokenCheck($token))
        
        $this->getResponse()->setHeader('Content-Type','application/json')
                            ->setHeader('X-JSON',Zend_Json::encode($payload))
                            ->appendBody('');
        return;
    } // public function getToken()
    
        
    public function toXml($dataArray,$callingMethod,$parameterValue)
    {
        
        $simpleXml = simplexml_load_string("<?xml version='1.0' encoding='utf-8'?><data />");
        $node = $simpleXml->addChild('results');
        $node->addChild('calling_method',$callingMethod);
        $node->addChild('parameter',$parameterValue);
        $node->addChild('row_count',count($dataArray));        
        
        foreach($dataArray as $keywordArray) {
            $node = $simpleXml->addChild('word');
            $node->addChild('keyword',$keywordArray['keyword']);
            $node->addChild('keyword_count',$keywordArray['keyword_count']);
        } // foreach($results as $keywordArray)
        
        $xml = $simpleXml->asXML();
        $simpleXml = null;
        
        return $xml;
    } // protected function toXml($dataArray,$callingMethod,$parameterValue)

    public function testAction()
    {
        echo 'Ping';
        return;
    }
} // class ApiController extends BaseController
