<?PHP
/*
* Setup the include path.
*/
$lib_paths = array();
$lib_paths[] = "c:/web/htdocs/app";
$lib_paths[] = "c:/web/zendlib/library";
$lib_paths[] = "c:/web/htdocs/lib/";

$inc_path  = implode(PATH_SEPARATOR, $lib_paths);
set_include_path($inc_path);


/*
 * grab all the necessary files for processing.
 */ 
require_once 'Cal/Controller/Request/Cli.php'; 
require_once 'Zend/Controller/Response/Cli.php'; 
require_once 'Zend/Controller/Response/Http.php'; 
require_once 'Zend/Controller/Front.php'; 
require_once 'Cal/Controller/Router.php';

/*
 * pick up the server specific configuration
 */
require_once 'config/Globals.php';
$config = Globals::getConfig();




/*
 * Define the rules for Getopt to parse the command line options.
 *
 * There are 3 magic rules that, if set, will be used:
 * $rules['m|module-s']     = '';
 * $rules['c|controller-s'] = '';
 * $rules['a|action-s']     = '';
 *
 * Otherwise you have to set the module, controller, and action manually.
 */ 
$rules = array(); 
$rules['m|module-s']     = 'The optional module to use.';
$rules['c|controller=s'] = 'The controller to use.'; 
$rules['a|action=s']     = 'The action to use.';

// custom rules
$rules['all']            = 'If set, the entire cache will be destroyed.';
$rules['v|verbose']      = 'If set, exceptions and othe debugging infomration will be displayed.'; 

 
/*
 * Misc setup
 */
ini_set('session.save_path',Globals::getConfig()->dirs->tmpDir);


/*
* Finally, the moment we've all been waiting for.
* Execution time.
*/
try {
    /*
     * Get an instance of our custom request class.
     */
    $request = new Zend_Controller_Request_Cli($rules);

    /*
     * Since we have to set some options manually, we need to get an instance of
     * the front controller and configure it for our needs.
     */ 
    $front = Zend_Controller_Front::getInstance();
    $front->setParam('noViewRenderer', true);
    $front->setParam('noErrorHandler', true); 
    $front->setRouter(new Cal_Controller_Router());
    $front->setRequest($request);
    $front->setResponse(new Zend_Controller_Response_Cli());
    $front->setControllerDirectory('controllers/');

    /*
     * Make a decision based on one of the parameters.  Ok, it's not the most
     * useful use of command line parameters but it does show how we would use
     * them.  In this case, if we pass in the -v option, the front controller
     * will actually show us a debug stack trace if we hit an error.
     */
    $front->throwExceptions($request->getOption('verbose'));
    
    /*
     * finally, do the deed
     */
    $front->dispatch();
    
} catch (Exception $exp) {
    /*
     * If the -v flag was passed in and you hit an error, you need to
     * display it.
     */
    $contentType = 'text/html';
    header("Content-Type: $contentType; charset=utf-8");
    echo 'an unexpected error occured.';
    echo '<h2>Unexpected Exception: ' . $exp->getMessage() . '</h2><br /><pre>';
    echo $exp->getTraceAsString();
    die($exp->getCode());
} // try

/*
 * Finally, if your script makes it this far, it's been well behaved.
 * Let it die gracefully.
 */
die(0);
